@@ -15,7 +15,7 @@ from django.conf import settings
 
 import time
 
-class BDDAbstractTestCase():
+class BDDBaseTestCase():
 
     def extra_setup(self):
         pass
@@ -39,11 +39,6 @@ class BDDAbstractTestCase():
         """
         pass
 
-class BDDCoreTestCase(BDDAbstractTestCase,TestCase):
-    pass
-
-class BDDTestCase(BDDAbstractTestCase, LiveServerTestCase):
-
     def parse_feature_file(self, app=None, file_path=None, scenarios=None):
 
         """
@@ -71,6 +66,11 @@ class BDDTestCase(BDDAbstractTestCase, LiveServerTestCase):
         new_dt += datetime.timedelta(days=add_days)
         return new_dt.strftime( format )
 
+class BDDCoreTestCase(BDDBaseTestCase,TestCase):
+    pass
+
+class BDDTestCase(BDDBaseTestCase, LiveServerTestCase):
+
     def click_element(self, find_methods, name):
         """
         Click an element
